<?php /* Template Name: Coffee Label */ 

$order_id = sanitize_text_field($_GET['order_id']);
$order = wc_get_order($order_id);
$first_name = $order->get_billing_first_name();
$last_name = $order->get_billing_last_name();
$postcode = $order->get_billing_postcode();
$items = $order->get_items(); 
$order_date = $order->get_date_created()->date('d/m/Y');
$gift_message = $order->get_meta('_shipping_gift_message');

?>

<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Coffee Label</title>
  <link rel="preconnect" href="https://api/fonts.coollabs.io">
  <link href="https://fonts.googleapis.com/css2?family=Roboto+Condensed:wght@100..900&display=swap" rel="stylesheet">
  <link rel="stylesheet" href="style.css">
  <style>
    .container {
      display: flex;
      flex-wrap: wrap;
    }

    .label {
      width: 400px;
      height: 400px;
      border-radius: 50%;
      padding: 2rem;
      margin: 2rem;
      text-align: center;
      border: 1px solid gray;
      display: flex;
      align-items: center;
      justify-content: center;
      background: linear-gradient(
        0deg,
        rgba(255, 255, 255, 1) 28%,
        rgba(231, 184, 32, 1) 28%
      );
    }

    .label .product-details {
      font-family: 'Roboto Condensed';
      font-size: 21px;
      letter-spacing: 2px;
      text-transform: uppercase;
      margin-top: 2.5em;
      margin-bottom: 2em;
      font-weight: 500;
    }

    .label .product-details p {
      margin-block: 0.5em;
    }

    .label .product-details .origin {
      font-size: 28px;
      font-weight: 700;
      letter-spacing: 4px;
      margin-block: 1.2em 0.8em;
    }

    .label .product-details .weight {
      text-transform: lowercase;
      font-weight: bold;
      font-family: sans-serif;
      font-weight: 18px;
    }

    .label .product-details .code {
      letter-spacing: 10px;
      margin-top: 1.5em;
      font-size: 16px;
    }

    .label .order-details {
      padding-bottom: 1em;
      font-weight: 17px;
    }

    .label .order-details p {
      margin-block: 0.4em;
    }
  </style>
</head>
<body>
  <div class="container">
    <?php foreach ($items as $item) {
      // checking if product is a coffee
      $product_id = $item->get_product_id();
      $product_categories = get_the_terms($product_id, 'product_cat');
      $is_coffee = false;

      if (!empty($product_categories) && !is_wp_error($product_categories)) {
        foreach ($product_categories as $product_category) {
          if ($product_category->slug == 'coffee') {
            $is_coffee = true;
            break;
          }
        }
      }
      
      if ($is_coffee) {
        $quantity = $item->get_quantity();
        $product_name = $item->get_name();
        $brew_method = $item->get_meta('pa_brew-method');
        $weight = $item->get_meta('weight');
	$roast = get_field('roast_level', $product_id);
	$is_organic = get_field('is_organic', $product_id);
  
        for ($i = 0; $i < $quantity; $i++) { ?>
          <div class="label">
            <div>
              <div class="product-details">
                <p class="weight"><?php echo $weight; ?></p>
                <p class="origin"><?php echo $product_name; ?></p>
                <p class="bean-type"><?php echo $brew_method; ?></p>
                <p class="roast"><?php echo $roast; ?> Roast</p>
                <p class="date">Roasted on: <span><?php echo $order_date; ?></span></p>
		            <p class="code">N<?php echo $gift_message ? 'G' : '' ?><?php echo $is_organic ? 'O' : '' ?></p>
              </div>
              <div class="order-details">
                <p class="customer-name"><?php echo "$first_name $last_name"; ?></p>
                <p class="purchase-code"><?php echo $postcode; ?></p>
                <p class="quantity"><?php echo $quantity; ?></p>
              </div>
            </div>
          </div>
        <?php } 
      }
    } ?>
  </div>
</body>
</html>
